@@ -53,15 +53,12 @@ class Feed : public RootItem {
     void setCountOfAllMessages(int count_all_messages);
     void setCountOfUnreadMessages(int count_unread_messages);
 
-    int autoUpdateInitialInterval() const;
-    void setAutoUpdateInitialInterval(int auto_update_interval);
+    int autoUpdateInterval() const;
+    void setAutoUpdateInterval(int auto_update_interval);
 
     AutoUpdateType autoUpdateType() const;
     void setAutoUpdateType(AutoUpdateType auto_update_type);
 
-    int autoUpdateRemainingInterval() const;
-    void setAutoUpdateRemainingInterval(int auto_update_remaining_interval);
-
     Status status() const;
     QString statusString() const;
     void setStatus(Feed::Status status, const QString& status_text = {});
@@ -75,11 +72,16 @@ class Feed : public RootItem {
     bool isSwitchedOff() const;
     void setIsSwitchedOff(bool switched_off);
 
+    bool isQuiet() const;
+    void setIsQuiet(bool quiet);
+
     void appendMessageFilter(MessageFilter* filter);
     QList<QPointer<MessageFilter>> messageFilters() const;
     void setMessageFilters(const QList<QPointer<MessageFilter>>& messageFilters);
     void removeMessageFilter(MessageFilter* filter);
 
+    QDateTime lastUpdated() const;
+    void setLastUpdated(const QDateTime& last_updated);
   public slots:
     virtual void updateCounts(bool including_total_count);
 
@@ -92,9 +94,10 @@ class Feed : public RootItem {
     Status m_status;
     QString m_statusString;
     AutoUpdateType m_autoUpdateType;
-    int m_autoUpdateInitialInterval{};
-    int m_autoUpdateRemainingInterval{};
+    int m_autoUpdateInterval{}; // In seconds.
+    QDateTime m_lastUpdated;
     bool m_isSwitchedOff;
+    bool m_isQuiet;
     bool m_openArticlesDirectly;
     int m_totalCount{};
     int m_unreadCount{};
