@@ -19,24 +19,19 @@ class QAction;
 // NOTE: This class is derived to add functionality for
 // all other non-root items of FeedsModel.
 class RSSGUARD_DLLSPEC RootItem : public QObject {
-  Q_OBJECT
+    Q_OBJECT
 
-  // Added for message filtering with labels.
-  Q_PROPERTY(QString title READ title)
-  Q_PROPERTY(QString customId READ customId)
+    // Added for message filtering with labels.
+    Q_PROPERTY(QString title READ title)
+    Q_PROPERTY(int id READ id)
+    Q_PROPERTY(QString customId READ customId)
 
   public:
-    enum class ReadStatus {
-      Unread = 0,
-      Read = 1
-    };
+    enum class ReadStatus { Unread = 0, Read = 1 };
 
     // Holds statuses for messages
     // to be switched importance (starred).
-    enum class Importance {
-      NotImportant = 0,
-      Important = 1
-    };
+    enum class Importance { NotImportant = 0, Important = 1 };
 
     // Describes the kind of the item.
     enum class Kind {
@@ -47,7 +42,8 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
       ServiceRoot = 16,
       Labels = 32,
       Important = 64,
-      Label = 128
+      Label = 128,
+      Unread = 256
     };
 
     // Constructors and destructors.
@@ -88,12 +84,16 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     virtual QList<Message> undeletedMessages() const;
 
     // This method should "clean" all messages it contains.
-    // What "clean" means? It means delete messages -> move them to recycle bin
+    //
+    // NOTE: What "clean" means? It means delete messages -> move them to recycle bin
     // or eventually remove them completely if there is no recycle bin functionality.
     //
     // If this method is called on "recycle bin" instance of your
     // service account, it should "empty" the recycle bin.
     virtual bool cleanMessages(bool clear_only_read);
+
+    // Reloads current counts of articles in this item from DB and
+    // sets.
     virtual void updateCounts(bool including_total_count);
     virtual int row() const;
     virtual QVariant data(int column, int role) const;
@@ -113,6 +113,8 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     int childCount() const;
     void appendChild(RootItem* child);
     QList<RootItem*> childItems() const;
+    QList<RootItem*>& childItems();
+
     void clearChildren();
     void setChildItems(const QList<RootItem*>& child_items);
 
@@ -142,7 +144,8 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     // Returns list of feeds complemented by their own string CUSTOM ID.
     QHash<QString, Feed*> getHashedSubTreeFeeds() const;
     QList<Feed*> getSubTreeFeeds() const;
-    QList<Feed*> getSubTreeManuallyIntervaledFeeds() const;
+    QList<Feed*> getSubTreeAutoFetchingWithManualIntervalsFeeds() const;
+    QList<Feed*> getSubAutoFetchingEnabledFeeds() const;
 
     // Returns the service root node which is direct or indirect parent of current item.
     ServiceRoot* getParentServiceRoot() const;
@@ -161,12 +164,17 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     // This ALWAYS represents primary column number/ID under which
     // the item is stored in DB.
     int id() const;
+
+    // WARNING: Do not EVER call this method if your "this" object is derived
+    // from "ServiceRoot";
     void setId(int id);
 
     // Each item has its title.
     QString title() const;
+    QString sanitizedTitle() const;
     void setTitle(const QString& title);
 
+    // This should be in UTC and should be converted to localtime when needed.
     QDateTime creationDate() const;
     void setCreationDate(const QDateTime& creation_date);
 
@@ -187,6 +195,20 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     bool keepOnTop() const;
     void setKeepOnTop(bool keep_on_top);
 
+    // Sort order, when items in feeds list are sorted manually.
+    //
+    // NOTE: This is only used for "Account", "Category" and "Feed" classes
+    // which can be manually sorted. Other types like "Label" cannot be
+    // automatically sorted and are always sorted by title.
+    //
+    // Sort order number cannot be negative but order of list of items with same
+    // parent MUST form continuous series AND start with zero, for example:
+    //   0, 1, 2, 3, 4, ...
+    //
+    // NOTE: This is checked with DatabaseQueries::fixupOrders() method on app startup.
+    int sortOrder() const;
+    void setSortOrder(int sort_order);
+
   private:
     RootItem::Kind m_kind;
     int m_id;
@@ -196,6 +218,7 @@ class RSSGUARD_DLLSPEC RootItem : public QObject {
     QIcon m_icon;
     QDateTime m_creationDate;
     bool m_keepOnTop;
+    int m_sortOrder;
     QList<RootItem*> m_childItems;
     RootItem* m_parentItem;
 };
@@ -227,6 +250,10 @@ inline QList<RootItem*> RootItem::childItems() const {
   return m_childItems;
 }
 
+inline QList<RootItem*>& RootItem::childItems() {
+  return m_childItems;
+}
+
 inline void RootItem::clearChildren() {
   m_childItems.clear();
 }
